The highest tagged major version is
v2.
package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Aug 29, 2017
License: GPL-3.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 20
Opens a new window with list of known importers.
README
¶

kmutex
Sync primitive for golang. Allow block part of resource by unique ID.
GO PLAYGROUND EXAMPLE
Documentation
¶
Package kmutex is synchronization primitive. Mutex which can be locked by unique ID.
Key + Mutex = Kmutex
Can be locked by unique ID
Create new Kmutex with user provided lock
func (km *Kmutex) Lock(key interface{})
Lock Kmutex by unique ID
Return a object which implement sync.Locker interface
A Locker represents an object that can be locked and unlocked.
func (km *Kmutex) Unlock(key interface{})
Unlock Kmutex by unique ID
Source Files
¶
Click to show internal directories.
Click to hide internal directories.